==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/fr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activité",
    "Personal activity feed for %s" : "Flux d'activité personnel de %s",
    "Your feed URL is invalid" : "Votre adresse de flux est n'est pas valide",
    "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
    "This stream will show events like additions, changes & shares" : "Ce flux montre les événements tel que les additions, les modifications et les partages",
    "There are no events for this filter" : "Il n'y a pas d'événement pour ce filtre",
    "Activity notification" : "Notification d'activité",
    "All Activities" : "Toutes activités",
    "Activities by you" : "Vos activités",
    "Activities by others" : "L'activité des autres",
    "\"remote user\"" : "\"utilisateur distant\"",
    "in %s" : "dans %s",
    "%s and %s" : "%s et %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s et <strong class=\"tooltip\" title=\"%s\">%n autre</strong>","%s et <strong class=\"tooltip\" title=\"%s\">%n autres</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s et %n autre","%s et %n autres"],
    "Hello %s," : "Bonjour %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Vous recevez ce courriel car pendant l'heure précédente l'activité suivante a eu lieu sur %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Vous recevez ce courriel car hier l'activité suivante a eu lieu sur %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Vous recevez ce courriel car la semaine dernière l'activité suivante a eu lieu sur %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* et %n autre","* et %n autres"],
    "Notifications" : "Notifications",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "List your own actions in the stream" : "Lister mes propres actions dans le flux",
    "Notify about your own actions via email" : "M'informer de mes propres actions par courriel",
    "You need to set up your email address before you can receive notification emails." : "Il est nécessaire de configurer une adresse courriel avant de pouvoir recevoir les notifications par courriel.",
    "Send emails:" : "Envoyer des courriels :",
    "Hourly" : "Toutes les heures",
    "Daily" : "Quotidiennement",
    "Weekly" : "Chaque semaine",
    "Activity feed" : "Flux d'activité",
    "Enable RSS feed" : "Activer les flux RSS",
    "No activity yet" : "Pas d'activité pour le moment",
    "No more events to load" : "Plus aucun événement à charger",
    "Files" : "Fichiers"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/fr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activité",
    "Personal activity feed for %s" : "Flux d'activité personnel de %s",
    "Your feed URL is invalid" : "Votre adresse de fil d’activité n'est pas valide",
    "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "Activities" : "Activité",
    "Error loading activities" : "Erreur au chargement de l'activité",
    "No activities" : "Aucune activité",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} et {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} et {linkStart}%n autre{linkEnd}","{parameterList} et {linkStart}%n autres{linkEnd}"],
    "in {directory}" : "dans {directory}",
    "This stream will show events like additions, changes & shares" : "Ce flux montre les événements tels que les ajouts, les modifications et les partages",
    "There are no events for this filter" : "Il n'y a pas d'événement pour ce filtre",
    "Today" : "Auj.",
    "Yesterday" : "Hier",
    "\"remote user\"" : "\"utilisateur distant\"",
    "Activity notification" : "Notification d'activité",
    "All Activities" : "Toutes activités",
    "Activities by you" : "Vos activités",
    "Activities by others" : "L'activité des autres",
    "%s and %s" : "%s et %s",
    "Hello %s," : "Bonjour %s,",
    "You are receiving this email because the following things happened at %s" : "Vous recevez ce message car l'activité suivante a eu lieu sur %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* et %n autre","* et %n autres"],
    "List your own actions in the stream" : "Lister mes propres actions dans le flux",
    "Notify about your own actions via email" : "M'informer de mes propres actions par courriel",
    "You need to set up your email address before you can receive notification emails." : "Il est nécessaire de configurer une adresse courriel avant de pouvoir recevoir les notifications par courriel.",
    "Send emails:" : "Envoyer des courriels :",
    "Hourly" : "Toutes les heures",
    "Daily" : "Quotidiennement",
    "Weekly" : "Chaque semaine",
    "Activity feed" : "Fil d'activité",
    "Enable RSS feed" : "Activer les flux RSS",
    "No activity yet" : "Pas d'activité pour le moment",
    "No more events to load" : "Plus aucun événement à charger",
    "Files" : "Fichiers"
},
"nplurals=2; plural=(n > 1);");
